Bookstore Client
================

The ``bookstore.client.store_client`` module
--------------------------------------------

.. module:: bookstore.client.store_client

``BookstoreClient``
~~~~~~~~~~~~~~~~~~~

.. autoclass:: BookstoreClient
   :members:
   :show-inheritance: